@@ -1,6 +1,6 @@
 #!/bin/sh
 #set -xv
-UPGRADE_VER="0.0.4"
+UPGRADE_VER="0.0.7"
 BIN_PATH="/home/root"
 CARD_PATH=${MOUNTR}
 UPGRADE_MD5="upgrade.md5"
@@ -23,13 +23,13 @@ RESC_RTFS_OFS=0xA00000
 DIAG_DD_DEV=/dev/mtdblock8
 
 do_reboot() {
-  if [ -f ${CARD_PATH}/upl_start.log ]; then
+#  if [ -f ${CARD_PATH}/upl_start.log ]; then
     echo "Removing temporary files from ${CARD_PATH}" | tee -a ${LOG}
     rm -f ${CARD_PATH}/${RTFS_NAME}* ${CARD_PATH}/${KERN_NAME}* ${CARD_PATH}/${BOOT_NAME}* ${CARD_PATH}/upl_start.log
     rm -f ${CARD_PATH}/${UPGRADE_MD5} ${CARD_PATH}/${NWRITE_NAME} ${CARD_PATH}/${PROD_NAME}
     rm -f ${CARD_PATH}/*.ta_
     rm -f ${CARD_PATH}/${UPGRADE_SH}
-  fi
+#  fi
   echo "Message:${2}" | tee -a ${LOG}
   # !The next should be the lats message in uploading.log!
   echo "Exit code is ${1}" | tee -a ${LOG}
@@ -38,7 +38,7 @@ do_reboot() {
 }
 
 do_file_check() {
- echo "Check file ${1}" | tee -a ${LOG}
+ echo "[$(cat /proc/uptime | cut -d ' ' -f1)] Check file ${1}" | tee -a ${LOG}
  hash1=`grep ${1} ${UPGRADE_MD5} | awk '{split($0,x," ");printf("%s",x[1])}'`
  echo "Orig hash $hash1" | tee -a ${LOG}
  hash2=$(md5sum ${1} | awk '{split($0,x," ");printf("%s",x[1])}')
@@ -69,38 +69,46 @@ do_sys_check() {
  echo "chk_hash  $chk_hash" | tee -a ${LOG}
  echo "orig_hash $orig_hash" | tee -a ${LOG}
  if [ "${chk_hash}" != "${orig_hash}" ]; then
-  echo "${1} md5sum differ" | tee -a ${LOG}
+  echo "[$(cat /proc/uptime | cut -d ' ' -f1)] ${1} md5sum differ" | tee -a ${LOG}
   ret=1
  else 
-  echo "${1} md5sum Ok" | tee -a ${LOG}
+  echo "[$(cat /proc/uptime | cut -d ' ' -f1)] ${1} md5sum Ok" | tee -a ${LOG}
   ret=0
  fi
 }
 
 do_sys_write() {
  # Img.Name, Offs, Dev.Name
+ /usr/local/bin/wd_ping -1 > /dev/null
  do_sys_check $1 $2 $3
  if [ $ret -ne 0 ]; then
-  echo "wr img:${1} to dev:${3} offs:${2}" | tee -a ${LOG}
+  echo "[$(cat /proc/uptime | cut -d ' ' -f1)] wr img:${1} to dev:${3} offs:${2}" | tee -a ${LOG}
+  /usr/local/bin/wd_ping -1 > /dev/null
   $NAND_WR -d ${3} -o ${2} -i ${CARD_PATH}/${1} | tee -a ${LOG}
   if [ $? -ne 0 ]; then
-	echo "${1} record failure" | tee -a ${LOG}
+	echo "[$(cat /proc/uptime | cut -d ' ' -f1)] ${1} record failure" | tee -a ${LOG}
 	ret=1
   else
-    echo "img:${1} on dev:${3} offs:${2} write Ok" | tee -a ${LOG}
+    echo "[$(cat /proc/uptime | cut -d ' ' -f1)] img:${1} on dev:${3} offs:${2} write Ok" | tee -a ${LOG}
     ret=0
   fi
  else
-  echo "img:${1} on dev:${3} offs:${2} is the same. Write skipped" | tee -a ${LOG}
+  echo "[$(cat /proc/uptime | cut -d ' ' -f1)] img:${1} on dev:${3} offs:${2} is the same. Write skipped" | tee -a ${LOG}
  fi
 }
 
 # start from here
 cd ${CARD_PATH}
 rm -f ${LOG}
-echo "Starting upgrade script ${UPGRADE_VER} at " $(date) "smod=$smod" | tee -a ${LOG}
+echo "[$(cat /proc/uptime | cut -d ' ' -f1)] Starting upgrade script ${UPGRADE_VER} at " $(date) "smod=$smod" | tee -a ${LOG}
 ps | grep wd_ping | awk '{split($0,x," ");printf("%s ",x[1])}' | xargs kill
-/usr/local/bin/wd_ping -30 -p &
+sleep 1
+/usr/local/bin/wd_ping -60 -p | tee -a ${LOG} &
+ret=$?
+echo "wd_ping ret $ret" | tee -a ${LOG}
+if [ $ret -ne 0 ]; then
+/usr/local/bin/wd_ping -60 -p | tee -a ${LOG} &
+fi
 uname -a | tee -a ${LOG}
 mount | tee -a ${LOG}
 ps | grep wd_ping | tee -a ${LOG}
@@ -113,13 +121,13 @@ fi
 pwd | tee -a ${LOG}
 tar -x${TAR_OPT} ${TAR_FILE} ${PROD_NAME}
 ls -l * | tee -a ${LOG}
+
+if [ ! "$(cat ${BIN_PATH}/${PROD_NAME} | awk '{split($0,x,"_");printf("%s",x[2])}')" == "rescue" ]; then
 WAR_FILE=${BIN_PATH}/${WARTOOL}
-if [ -f ${WAR_FILE} ];
-then
+ if [ -f ${WAR_FILE} ]; then
  echo "Checking Warr at " $(date) | tee -a ${LOG}
  ${WAR_FILE} ./${PROD_NAME}
- if [ $? -eq 0 ];
- then
+ if [ $? -eq 0 ]; then
   echo "Error to upgrade. Warranty period exceeds !!!" | tee -a ${LOG}
   echo "Ending upgrade script at " $(date) | tee -a ${LOG}
   echo "SMOD 0" > /proc/sp4
@@ -128,6 +136,9 @@ then
   do_reboot -1 "Not Allowed"
  fi
 fi
+else
+ echo "Rescue mode. Skip Warr"
+fi
 
 fl_kupl=0
 /usr/local/bin/blaze_leds on FF
@@ -195,7 +206,7 @@ if [ "${fl_kupl}" -ne "1" ]; then
 fi
 
 # Resc
-echo "Write rescue" | tee -a ${LOG}
+echo "[$(cat /proc/uptime | cut -d ' ' -f1)] Write rescue" | tee -a ${LOG}
 do_sys_write ${BOOT_NAME} $RESC_BOOT_OFS $RESC_DD_DEV
 echo "ret $ret" | tee -a ${LOG}
 do_sys_write ${KERN_NAME} $RESC_KERN_OFS $RESC_DD_DEV
@@ -204,7 +215,7 @@ do_sys_write ${RTFS_NAME} $RESC_RTFS_OFS $RESC_DD_DEV
 echo "ret $ret" | tee -a ${LOG}
 
 # Main
-echo "Write main" | tee -a ${LOG}
+echo "[$(cat /proc/uptime | cut -d ' ' -f1)] Write main" | tee -a ${LOG}
 do_sys_write ${BOOT_NAME} 0 $BOOT_DD_DEV
 echo "ret $ret" | tee -a ${LOG}
 do_sys_write ${KERN_NAME} 0 $KERN_DD_DEV
@@ -226,7 +237,7 @@ cd /mnt/bin
 rm -f CHAN PVT SL sp4*.sh bt_iap pvt_storage.txt productVersion.txt processLauncher
 rm -rf www
 sync
-echo "Removing prev.data complete" | tee -a ${LOG}
+echo "[$(cat /proc/uptime | cut -d ' ' -f1)] Removing prev.data complete" | tee -a ${LOG}
 
 echo "SMOD 0" > /proc/sp4
 echo "UCMD STRT" > /proc/sp4
